
import com.yourkit.api.Controller;
import com.yourkit.api.MemorySnapshot;

import java.io.File;

public class APIDemo2 {
  public static void main(final String[] args) throws Exception {

    // Create a controller for a profiled application.
    // Use Controller() to self-profile application or Controller(String host, int port)
    // to profile any application.
    final Controller controller = new Controller();

    final String snapshotFileName;
    try {
      // Capture snapshot
      snapshotFileName = controller.captureMemorySnapshot();
    }
    catch (Exception ex) {
      System.out.println("Cannot capture snapshot. Reason: " + ex.getMessage());
      ex.printStackTrace();
      return;
    }

    System.out.println("The application has captured its own memory snapshot.\nIt is saved to the file " + snapshotFileName);

    System.out.println();
    System.out.println("Loading captured snapshot...");
    try {
      // Load snapshot for analysis
      final MemorySnapshot snapshot = new MemorySnapshot(new File(snapshotFileName), null, null);

      // Get and print some statistics

      final String classesDescription = "<objects class=\"java.lang.Class\"/>";
      final String objectsDescription = "<objects class=\"java.lang.Object\"/>";
      final String stringsDescription = "<objects class=\"java.lang.String\"/>";

      System.out.println();
      System.out.println("Total number of classes: " + snapshot.getObjectCount(classesDescription));
      System.out.println();
      System.out.println("Total number of objects: " + snapshot.getObjectCount(objectsDescription));
      System.out.println("Size of all objects: " + snapshot.getShallowSize(objectsDescription));
      System.out.println();
      System.out.println("Number of strings: " + snapshot.getObjectCount(stringsDescription));
      System.out.println("Shallow size of all strings: " + snapshot.getShallowSize(stringsDescription));
      System.out.println("Retained size of all strings: " + snapshot.getShallowSize(
        "<retained-objects>" + stringsDescription + "</retained-objects>")
      );

    }
    catch (Exception ex) {
      System.out.println("Cannot load captured snapshot. Reason: " + ex.getMessage());
      ex.printStackTrace();
    }
  }
}
